==> haskell-project-template-0.2.1.0-369-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 project-template
version:              0.2.1.0
visibility:           public
id:                   project-template-0.2.1.0-CA7i89Vogkv29dOrlTmkZV
key:                  project-template-0.2.1.0-CA7i89Vogkv29dOrlTmkZV
license:              BSD-3-Clause
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/haskell-ide
synopsis:             Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>

category:             Development
abi:                  5a8bff892f7a0499d8108173f23a8c5f
exposed:              True
exposed-modules:      Text.ProjectTemplate
import-dirs:          /usr/lib/ghc-9.2.8/site-local/project-template-0.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/project-template-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-project-template
hs-libraries:         HSproject-template-0.2.1.0-CA7i89Vogkv29dOrlTmkZV
depends:
    base-4.16.4.0 base64-bytestring-1.2.1.0-46pt6JzDe5g8aYRwkMhuBg
    bytestring-0.11.4.0 conduit-1.3.6-7XhR2ax9qCFCYitRevMXBd
    conduit-extra-1.3.6-LNjgpnvA8Q8Ct50nG3gLWQ containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2
    resourcet-1.2.6-LfGMMseD8gYHfEEaghmlUT text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-project-template/html/project-template.haddock

haddock-html:         /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-project-template-0.2.1.0-370-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 project-template
version:              0.2.1.0
visibility:           public
id:                   project-template-0.2.1.0-KSZbwN0XLSZD61ZAw6yUzk
key:                  project-template-0.2.1.0-KSZbwN0XLSZD61ZAw6yUzk
license:              BSD-3-Clause
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/haskell-ide
synopsis:             Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>

category:             Development
abi:                  24cfbfabe007496d88fe895871304e0e
exposed:              True
exposed-modules:      Text.ProjectTemplate
import-dirs:          /usr/lib/ghc-9.2.8/site-local/project-template-0.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/project-template-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-project-template
hs-libraries:         HSproject-template-0.2.1.0-KSZbwN0XLSZD61ZAw6yUzk
depends:
    base-4.16.4.0 base64-bytestring-1.2.1.0-EN8wQYcxk0e9hsUIf9btXq
    bytestring-0.11.4.0 conduit-1.3.6-FkwDYZYBN2n9gztrYJLrBN
    conduit-extra-1.3.6-UL8MowVobvFqAEIggQNDe containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2
    resourcet-1.2.6-Bsii0ofts3VF0aGJ0EExRr text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-project-template/html/project-template.haddock

haddock-html:         /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
